/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) Original Authors
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::dynamicWhiplashFvMesh

Description
    Mesh motion specifically for the "pumping" system of an ink-jet
    injector.

    The set of points in the "pumping" region are compressed and expanded
    sinusoidally to impose a sinusoidal variation of the flow at the
    nozzle exit.

SourceFiles
    dynamicWhiplashFvMesh.C

Authors
    Håkan Nilsson
    OpenCFD

\*---------------------------------------------------------------------------*/

#ifndef dynamicWhiplashFvMesh_H
#define dynamicWhiplashFvMesh_H

#include "dynamicFvMesh.H"
#include "dictionary.H"
#include "pointIOField.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                           Class dynamicWhiplashFvMesh Declaration
\*---------------------------------------------------------------------------*/

class dynamicWhiplashFvMesh
:
    public dynamicFvMesh
{
    // Private data

        dictionary dynamicMeshCoeffs_;

        float P_[255][6], Y_[255][7];             /*P: coefficient Y: coordinate*/

        pointIOField newPoints_;

    // Private Member Functions

        //- Disallow default bitwise copy construct
        dynamicWhiplashFvMesh(const dynamicWhiplashFvMesh&);

        //- Disallow default bitwise assignment
        void operator=(const dynamicWhiplashFvMesh&);


public:

    //- Runtime type information
    TypeName("dynamicWhiplashFvMesh");


    // Constructors

        //- Construct from IOobject
        dynamicWhiplashFvMesh(const IOobject& io);


    // Destructor

        ~dynamicWhiplashFvMesh();


    // Member Functions

        //- Update the mesh for both mesh motion and topology change
        virtual bool update();
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
