function PlotAngle(angles, figureNumber)
%PlotAngle(angles)
%PlotAngle(angles, figureNumber)
% This function plots the calculated rotational angles using AngleSpline().
%
% This function is developed in September 2007
%  Feng Liu
%  Vehicle Safety Division
%  Chalmers University of Technology
%  liu.peak@gmail.com
% Revisions
%--------------------
% February 2009, add comments, separate from AngleSpline.m
if nargin == 1
    figureNumber = 1;
end
time = [0 25 50 65 100 150 200 250 300]; %Initial time vector
figure(figureNumber)
hold on
[row,col] = size(angles);
tss = (time(end)+1)/row;
time_vec  = time(1):tss:time(end);
interval = floor(row/15);
for iCV = 2
    symbol = ChooseSymbol(iCV);
    plot(time_vec(1:interval:end), angles(1:interval:end,iCV), symbol)
end
plot(time_vec, angles(:,2),'-b')
for iCV = 3 : 6
    symbol = ChooseSymbol(iCV);
    plot(time_vec, angles(:,iCV), symbol)
end
axis([0 300 -10 60])
grid on
legend('c6','c5','c4','c3','c2','Location','Best')
ylabel('Rotational angle [Degree]')
xlabel('Time [ms]')
title('The time history of each vertebra rotational angle (interpolation)')
hold off

function symbol = ChooseSymbol(id)
%symbol = ChooseSymbol(id)
% The usage of this function is to choose a symbol for plot.
switch id
        case 1
            symbol='xb';
            
        case 2
            symbol='db';
            
        case 3
            symbol='--b';
           
        case 4
            symbol='-.b';
            
        case 5
            symbol=':b';
            
        case 6
            symbol='-b';
            
        case 7
            symbol='.b';
end